get file='wm.sav'.

select if (WM7 = 1).

weight by wmweight.

compute total = 1.
variable label total "Number of women".
value label total 1 "".

* Select for women who have hemoglobin measurements.
select if (HE1 = 1).

* if we have altitude, then set alt equal to the altitude (in metres) for each cluster.
compute alt = 0.
* Convert from metres into thousands of feet.
compute altadj = alt * 3.3 / 1000.
compute adjust = 0 - 0.032*altadj + 0.022*altadj*altadj.
if (adjust < 0) adjust = 0.
compute adjHE2 = HE2 - adjust.

* Smoking adjustment.
recode sm2 (0 thru 9 = 0) (10 thru 19 = -0.3) (20 thru 39 = -0.5) (40 thru 97 = -0.7) (98 thru 99 = -0.3) (else=0) into smadj.

compute adjHE2 = adjHE2 + smadj.

* Currently pregnant women have different cut-offs.
do if (CP1 = 1).
+ recode adjHE2 (lo thru 6.99 = 3) (7 thru 9.99 = 2) (10 thru 10.99 = 1) (else = 0) into anemia.
else.
+ recode adjHE2 (lo thru 6.99 = 3) (7 thru 9.99 = 2) (10 thru 11.99 = 1) (else = 0) into anemia.
end if.
variable label anemia "Anemia status".
value label anemia 0 "No anemia" 1 "Mild anemia" 2 "Moderate anemia" 3 "Severe anemia".

recode anemia (1 thru 3=100) (else=0) into anyanem.

recode ceb (1=1)(2=2)(3 thru hi=3).
value labels ceb 1 "1" 2 "2" 3 "3+".
variable label ceb "Number of children ever born".

* Group unsured/DK with not pregnant.
recode cp1 (8=2).

* Drop rows with small cell sizes.
recode hc1c (4=7)(9=sysmis).
recode melevel (9=sysmis).
compute total1 = 1.
value label total1 1 "Total".

tables
  /format = zero
  /observation anyanem
  /ftotal = tot2 "Total"
  /table = HH7 + HH6 + wage + ceb + CP1 + sm1 + melevel + wlthind5 + hc1c + total1 by
    anemia + tot2 + anyanem
  /statistics
    cpct(anemia (f5.1) '' :HH7 HH6 wage ceb cp1 sm1 melevel wlthind5 hc1c total1)
    mean(anyanem (f5.1) 'Any anemia')
    validn(anyanem (f5.0) 'Number of women')
  /title
    "Table HE.1: Prevalence of anemia in women"
    "Percentage of women aged 15-49 years with anemia by background characteristics, Georgia, 2005"
  /caption
    "Anemia levels:"
    "Not pregnant - Mild = 10.0-11.9 g/dl, Moderate = 7.0-9.9 g/dl, Severe = < 7.0 g/dl"
    "Currently pregnant - Mild = 10.0-10.9 g/dl, Moderate = 7.0-9.9 g/dl, Severe = < 7.0 g/dl".
                                                                                                                                
new file.
  